@@ -1,5 +1,5 @@
 /* od -- dump files in octal and other formats
-   Copyright (C) 92, 1995-2001 Free Software Foundation, Inc.
+   Copyright (C) 92, 1995-2002 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -282,7 +282,11 @@ of FILE to standard output.  With more than one FILE argument,\n\
 concatenate them in the listed order to form the input.\n\
 With no FILE, or when FILE is -, read standard input.\n\
 \n\
+"), stdout);
+      fputs (_("\
 Mandatory arguments to long options are mandatory for short options too.\n\
+"), stdout);
+      fputs (_("\
   -A, --address-radix=RADIX   decide how file offsets are printed\n\
   -j, --skip-bytes=BYTES      skip BYTES input bytes first\n\
 "), stdout);
@@ -294,9 +298,9 @@ Mandatory arguments to long options are mandatory for short options too.\n\
   -w, --width[=BYTES]         output BYTES bytes per output line\n\
       --traditional           accept arguments in pre-POSIX form\n\
 "), stdout);
+      fputs (HELP_OPTION_DESCRIPTION, stdout);
+      fputs (VERSION_OPTION_DESCRIPTION, stdout);
       fputs (_("\
-      --help                  display this help and exit\n\
-      --version               output version information and exit\n\
 \n\
 Pre-POSIX format specifications may be intermixed, they accumulate:\n\
   -a   same as -t a,  select named characters\n\
@@ -330,21 +334,24 @@ TYPE is made up of one or more of these specifications:\n\
   o[SIZE]    octal, SIZE bytes per integer\n\
   u[SIZE]    unsigned decimal, SIZE bytes per integer\n\
   x[SIZE]    hexadecimal, SIZE bytes per integer\n\
+"), stdout);
+      fputs (_("\
 \n\
 SIZE is a number.  For TYPE in doux, SIZE may also be C for\n\
 sizeof(char), S for sizeof(short), I for sizeof(int) or L for\n\
-"), stdout);
-      fputs (_("\
 sizeof(long).  If TYPE is f, SIZE may also be F for sizeof(float), D\n\
 for sizeof(double) or L for sizeof(long double).\n\
+"), stdout);
+      fputs (_("\
 \n\
 RADIX is d for decimal, o for octal, x for hexadecimal or n for none.\n\
 BYTES is hexadecimal with 0x or 0X prefix, it is multiplied by 512\n\
-"), stdout);
-      fputs (_("\
 with b suffix, by 1024 with k and by 1048576 with m.  Adding a z suffix to\n\
 any type adds a display of printable characters to the end of each line\n\
-of output.  -s without a number implies 3.  -w without a number implies 32.\n\
+of output.  \
+"), stdout);
+      fputs (_("\
+-s without a number implies 3.  -w without a number implies 32.\n\
 By default, od uses -A o -t d2 -w 16.\n\
 "), stdout);
       puts (_("\nReport bugs to <bug-textutils@gnu.org>."));
@@ -1074,7 +1081,7 @@ skip (uintmax_t n_skip)
 		n_skip -= file_stats.st_size;
 	      else
 		{
-		  if (lseek (fileno (in_stream), n_skip, SEEK_CUR) < 0)
+		  if (fseeko (in_stream, n_skip, SEEK_CUR) != 0)
 		    {
 		      error (0, errno, "%s", input_filename);
 		      err = 1;
